.. currentmodule:: abjad.tools.sequencetools

partition_sequence_by_restricted_growth_function
================================================

.. autofunction:: partition_sequence_by_restricted_growth_function
